types

package
v0.0.0-...-d743d67 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 10, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

const (
	// VarIntMaxSize is the maximun size in bytes of a variable integer
	VarIntMaxSize = 9
)

Variables

This section is empty.

Functions

This section is empty.

Types

type VarInt

type VarInt int64

VarInt represents a variable integer More info https://en.wikipedia.org/wiki/Variable-length_quantity

func (VarInt) MarshalBinary

func (v VarInt) MarshalBinary() (data []byte, err error)

MarshalBinary encodes the variable integer into a binary form and returns the result.

func (*VarInt) UnmarshalBinary

func (v *VarInt) UnmarshalBinary(data []byte) error

UnmarshalBinary decodes the binary into a variable integer and sets the value.

Jump to