Documentation
¶
Index ¶
Constants ¶
const (
// VarIntMaxSize is the maximun size in bytes of a variable integer
VarIntMaxSize = 9
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type VarInt ¶
type VarInt int64
VarInt represents a variable integer More info https://en.wikipedia.org/wiki/Variable-length_quantity
func (VarInt) MarshalBinary ¶
MarshalBinary encodes the variable integer into a binary form and returns the result.
func (*VarInt) UnmarshalBinary ¶
UnmarshalBinary decodes the binary into a variable integer and sets the value.
Click to show internal directories.
Click to hide internal directories.